diff --git a/OvmfPkg/AcpiPlatformDxe/AcpiPlatformDxe.inf b/OvmfPkg/AcpiPlatformDxe/AcpiPlatformDxe.inf
index 055f3ad0ee0f..742ad8016c69 100644
--- a/OvmfPkg/AcpiPlatformDxe/AcpiPlatformDxe.inf
+++ b/OvmfPkg/AcpiPlatformDxe/AcpiPlatformDxe.inf
@@ -53,15 +53,15 @@ [LibraryClasses]
   MemoryAllocationLib
   BaseLib
   DxeServicesTableLib
   OrderedCollectionLib
 
 [Protocols]
   gEfiAcpiTableProtocolGuid                     # PROTOCOL ALWAYS_CONSUMED
-  gEfiPciEnumerationCompleteProtocolGuid        # PROTOCOL SOMETIMES_CONSUMED
+  gRootBusesConnectedProtocolGuid               # PROTOCOL SOMETIMES_CONSUMED
 
 [Guids]
   gEfiXenInfoGuid
 
 [Pcd]
   gEfiMdeModulePkgTokenSpaceGuid.PcdAcpiTableStorageFile
   gEfiMdeModulePkgTokenSpaceGuid.PcdPciDisableBusEnumeration
diff --git a/OvmfPkg/AcpiPlatformDxe/QemuFwCfgAcpiPlatformDxe.inf b/OvmfPkg/AcpiPlatformDxe/QemuFwCfgAcpiPlatformDxe.inf
index 22ce165852f9..5a01de58ed53 100644
--- a/OvmfPkg/AcpiPlatformDxe/QemuFwCfgAcpiPlatformDxe.inf
+++ b/OvmfPkg/AcpiPlatformDxe/QemuFwCfgAcpiPlatformDxe.inf
@@ -43,14 +43,14 @@ [LibraryClasses]
   OrderedCollectionLib
   QemuFwCfgLib
   UefiBootServicesTableLib
   UefiDriverEntryPoint
 
 [Protocols]
   gEfiAcpiTableProtocolGuid                     # PROTOCOL ALWAYS_CONSUMED
-  gEfiPciEnumerationCompleteProtocolGuid        # PROTOCOL SOMETIMES_CONSUMED
+  gRootBusesConnectedProtocolGuid               # PROTOCOL SOMETIMES_CONSUMED
 
 [Pcd]
   gEfiMdeModulePkgTokenSpaceGuid.PcdPciDisableBusEnumeration
 
 [Depex]
   gEfiAcpiTableProtocolGuid
diff --git a/OvmfPkg/AcpiPlatformDxe/EntryPoint.c b/OvmfPkg/AcpiPlatformDxe/EntryPoint.c
index d713b0d44b1b..dafdf8578265 100644
--- a/OvmfPkg/AcpiPlatformDxe/EntryPoint.c
+++ b/OvmfPkg/AcpiPlatformDxe/EntryPoint.c
@@ -9,15 +9,15 @@
   distribution.  The full text of the license may be found at
   http://opensource.org/licenses/bsd-license.php
 
   THE PROGRAM IS DISTRIBUTED UNDER THE BSD LICENSE ON AN "AS IS" BASIS, WITHOUT
   WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED.
 **/
 
-#include <Protocol/PciEnumerationComplete.h>
+#include <Protocol/RootBusesConnected.h>
 #include "AcpiPlatform.h"
 
 STATIC
 EFI_ACPI_TABLE_PROTOCOL *
 FindAcpiTableProtocol (
   VOID
   )
@@ -34,22 +34,23 @@ FindAcpiTableProtocol (
   return AcpiTable;
 }
 
 
 STATIC
 VOID
 EFIAPI
-OnPciEnumerated (
+OnRootBusesConnected (
   IN EFI_EVENT Event,
   IN VOID      *Context
   )
 {
   EFI_STATUS Status;
 
-  DEBUG ((EFI_D_INFO, "%a: PCI enumeration complete, installing ACPI tables\n",
+  DEBUG ((EFI_D_INFO,
+    "%a: root buses have been connected, installing ACPI tables\n",
     __FUNCTION__));
   Status = InstallAcpiTables (FindAcpiTableProtocol ());
   if (EFI_ERROR (Status)) {
     DEBUG ((EFI_D_ERROR, "%a: InstallAcpiTables: %r\n", __FUNCTION__, Status));
   }
   gBS->CloseEvent (Event);
 }
@@ -60,57 +61,58 @@ EFIAPI
 AcpiPlatformEntryPoint (
   IN EFI_HANDLE         ImageHandle,
   IN EFI_SYSTEM_TABLE   *SystemTable
   )
 {
   EFI_STATUS Status;
   VOID       *Interface;
-  EFI_EVENT  PciEnumerated;
+  EFI_EVENT  RootBusesConnected;
   VOID       *Registration;
 
   //
   // If the platform doesn't support PCI, or PCI enumeration has been disabled,
   // install the tables at once, and let the entry point's return code reflect
   // the full functionality.
   //
   if (PcdGetBool (PcdPciDisableBusEnumeration)) {
     DEBUG ((EFI_D_INFO, "%a: PCI or its enumeration disabled, installing "
       "ACPI tables\n", __FUNCTION__));
     return InstallAcpiTables (FindAcpiTableProtocol ());
   }
 
   //
   // Similarly, if PCI enumeration has already completed, install the tables
   // immediately.
   //
-  Status = gBS->LocateProtocol (&gEfiPciEnumerationCompleteProtocolGuid,
+  Status = gBS->LocateProtocol (&gRootBusesConnectedProtocolGuid,
                   NULL /* Registration */, &Interface);
   if (!EFI_ERROR (Status)) {
-    DEBUG ((EFI_D_INFO, "%a: PCI enumeration already complete, "
+    DEBUG ((EFI_D_INFO, "%a: root buses already connected, "
       "installing ACPI tables\n", __FUNCTION__));
     return InstallAcpiTables (FindAcpiTableProtocol ());
   }
   ASSERT (Status == EFI_NOT_FOUND);
 
   //
   // Otherwise, delay installing the ACPI tables until PCI enumeration
   // completes. The entry point's return status will only reflect the callback
   // setup.
   //
-  Status = gBS->CreateEvent (EVT_NOTIFY_SIGNAL, TPL_CALLBACK, OnPciEnumerated,
-                  NULL /* Context */, &PciEnumerated);
+  Status = gBS->CreateEvent (EVT_NOTIFY_SIGNAL, TPL_CALLBACK,
+                  OnRootBusesConnected, NULL /* Context */,
+                  &RootBusesConnected);
   if (EFI_ERROR (Status)) {
     return Status;
   }
 
-  Status = gBS->RegisterProtocolNotify (
-                  &gEfiPciEnumerationCompleteProtocolGuid, PciEnumerated,
-                  &Registration);
+  Status = gBS->RegisterProtocolNotify (&gRootBusesConnectedProtocolGuid,
+                  RootBusesConnected, &Registration);
   if (EFI_ERROR (Status)) {
-    gBS->CloseEvent (PciEnumerated);
+    gBS->CloseEvent (RootBusesConnected);
   } else {
-    DEBUG ((EFI_D_INFO, "%a: PCI enumeration pending, registered callback\n",
+    DEBUG ((EFI_D_INFO,
+      "%a: waiting for root buses to be connected, registered callback\n",
       __FUNCTION__));
   }
 
@@ -60,57 +61,58 @@ EFIAPI
 
   //
-  // Similarly, if PCI enumeration has already completed, install the tables
+  // Similarly, if root buses have already been connected, install the tables
   // immediately.
   //
@@ -60,57 +61,58 @@ EFIAPI
 
   //
-  // Otherwise, delay installing the ACPI tables until PCI enumeration
-  // completes. The entry point's return status will only reflect the callback
+  // Otherwise, delay installing the ACPI tables until root buses are
+  // connected. The entry point's return status will only reflect the callback
   // setup.
   //
   return Status;
 }
